==> fontbakery-0.13.0a1.tar.gz: fontbakery-0.13.0a1/tests/test_checks_iso15008.py <==
import sys

import pytest

from conftest import ImportRaiser, remove_import_raiser

from fontbakery.status import FAIL
from fontbakery.codetesting import (
    assert_PASS,
    assert_results_contain,
    CheckTester,
    TEST_FILE,
)


def test_extra_needed_exit(monkeypatch):
    module_name = "uharfbuzz"
    sys.meta_path.insert(0, ImportRaiser(module_name))
    monkeypatch.delitem(sys.modules, module_name, raising=False)
    from fontbakery.checks.iso15008 import pair_kerning

    with pytest.raises(SystemExit):
        pair_kerning(None, None, None)

    remove_import_raiser(module_name)


def test_check_iso15008_proportions():
    """Check if 0.65 => (H width / H height) => 0.80"""
    check = CheckTester("iso15008/proportions")

    # Cabin has a proportion of 0.7, so that's good.
    font = TEST_FILE("cabin/Cabin-Regular.ttf")
    assert_PASS(check(font), "with a good font...")

    # Wonky Paths doesn't have an H
    font = TEST_FILE("wonky_paths/WonkySourceSansPro-Regular.otf")
    assert_results_contain(
        check(font),
        FAIL,
        "glyph-not-present",
        "with a font that does not have an 'H' glyph...",
    )

    # Covered By Your Grace is really tall (proportion 0.39)
    font = TEST_FILE("coveredbyyourgrace/CoveredByYourGrace.ttf")
    assert_results_contain(
        check(font),
        FAIL,
        "invalid-proportion",
        "with a very tall font (proportion of 'H' width to 'H' height)...",
    )


def test_check_iso15008_stem_width():
    """Check if 0.10 <= (stem width / ascender) <= 0.82"""
    check = CheckTester("iso15008/stem_width")

    font = TEST_FILE("cabin/Cabin-SemiBold.ttf")
    assert_PASS(check(font), "with a good font...")

    # Wonky Paths doesn't have an 'l'
    font = TEST_FILE("wonky_paths/WonkySourceSansPro-Regular.otf")
    assert_results_contain(
        check(font), FAIL, "no-stem-width", "with a font lacking an 'l' glyph..."
    )

    # Cabin Regular is actually slightly too thin for displays
    font = TEST_FILE("cabin/Cabin-Regular.ttf")
    assert_results_contain(
        check(font),
        FAIL,
        "invalid-proportion",
        "with a too thin font (proportion of stem width to ascender)...",
    )


def test_check_iso15008_intercharacter_spacing():
    """Check if spacing between characters is adequate for display use"""
    check = CheckTester("iso15008/intercharacter_spacing")

    font = TEST_FILE("cabin/Cabin-Regular.ttf")
    assert_PASS(check(font), "with a good font...")

    font = TEST_FILE("cabin/Cabin-SemiBold.ttf")
    # l stem width is 111, LSB at x-height is 59, RSB at x-Height is 83
    # 142 / 111 = 128%, so this font is too tight.
    assert_results_contain(
        check(font),
        FAIL,
        "bad-vertical-vertical-spacing",
        "with a too tight font (space between vertical strokes)...",
    )

    # v LSB is 5, lv kern is -6 (!) so lv distance is 83+5-6 = 82
    # 82 / 111 = 0.73%, so that fails too.
    assert_results_contain(
        check(font),
        FAIL,
        "bad-vertical-diagonal-spacing",
        "with bad spacing between vertical and diagonal strokes...",
    )

    font = TEST_FILE("montserrat/Montserrat-Black.ttf")
    # vv touches
    assert_results_contain(
        check(font),
        FAIL,
        "bad-diagonal-diagonal-spacing",
        "with diagonal strokes (vv) that are touching...",
    )


def test_check_iso15008_interword_spacing():
    """Check if spacing between words is adequate for display use"""
    check = CheckTester("iso15008/interword_spacing")

    font = TEST_FILE("cabin/CabinCondensed-Bold.ttf")
    # lm space is 112; m+space+l space is 286; 286/112 = 255%
    assert_PASS(check(font), "with a good font...")

    font = TEST_FILE("cabin/Cabin-Regular.ttf")
    # lm space is 147; m+space+l space is 341; 341/147 = 232%
    assert_results_contain(
        check(font), FAIL, "bad-interword-spacing", "with bad interword space..."
    )


def test_check_iso15008_interline_spacing():
    """Check if spacing between lines is adequate for display use"""
    check = CheckTester("iso15008/interline_spacing")

    font = TEST_FILE("cabin/Cabin-Regular.ttf")
    assert_PASS(check(font), "with a good font...")

    font = TEST_FILE("source-sans-pro/TTF/SourceSansPro-Bold.ttf")
    # 39 units at bottom of g + 49 units at top of h + no typolinegap = 88
    # stem width = 147
    assert_results_contain(
        check(font), FAIL, "bad-interline-spacing", "with bad interline space..."
    )

==> fontbakery-1.0.1.tar.gz: fontbakery-1.0.1/tests/test_checks_iso15008.py <==
from conftest import check_id
from fontbakery.status import FAIL
from fontbakery.codetesting import (
    assert_PASS,
    assert_results_contain,
    TEST_FILE,
)


@check_id("iso15008/proportions")
def test_check_iso15008_proportions(check):
    """Check if 0.65 => (H width / H height) => 0.80"""

    # Cabin has a proportion of 0.7, so that's good.
    font = TEST_FILE("cabin/Cabin-Regular.ttf")
    assert_PASS(check(font), "with a good font...")

    # Wonky Paths doesn't have an H
    font = TEST_FILE("wonky_paths/WonkySourceSansPro-Regular.otf")
    assert_results_contain(
        check(font),
        FAIL,
        "glyph-not-present",
        "with a font that does not have an 'H' glyph...",
    )

    # Covered By Your Grace is really tall (proportion 0.39)
    font = TEST_FILE("coveredbyyourgrace/CoveredByYourGrace.ttf")
    assert_results_contain(
        check(font),
        FAIL,
        "invalid-proportion",
        "with a very tall font (proportion of 'H' width to 'H' height)...",
    )


@check_id("iso15008/stem_width")
def test_check_iso15008_stem_width(check):
    """Check if 0.10 <= (stem width / ascender) <= 0.82"""

    font = TEST_FILE("cabin/Cabin-SemiBold.ttf")
    assert_PASS(check(font), "with a good font...")

    # Wonky Paths doesn't have an 'l'
    font = TEST_FILE("wonky_paths/WonkySourceSansPro-Regular.otf")
    assert_results_contain(
        check(font), FAIL, "no-stem-width", "with a font lacking an 'l' glyph..."
    )

    # Cabin Regular is actually slightly too thin for displays
    font = TEST_FILE("cabin/Cabin-Regular.ttf")
    assert_results_contain(
        check(font),
        FAIL,
        "invalid-proportion",
        "with a too thin font (proportion of stem width to ascender)...",
    )


@check_id("iso15008/intercharacter_spacing")
def test_check_iso15008_intercharacter_spacing(check):
    """Check if spacing between characters is adequate for display use"""

    font = TEST_FILE("cabin/Cabin-Regular.ttf")
    assert_PASS(check(font), "with a good font...")

    font = TEST_FILE("cabin/Cabin-SemiBold.ttf")
    # l stem width is 111, LSB at x-height is 59, RSB at x-Height is 83
    # 142 / 111 = 128%, so this font is too tight.
    assert_results_contain(
        check(font),
        FAIL,
        "bad-vertical-vertical-spacing",
        "with a too tight font (space between vertical strokes)...",
    )

    # v LSB is 5, lv kern is -6 (!) so lv distance is 83+5-6 = 82
    # 82 / 111 = 0.73%, so that fails too.
    assert_results_contain(
        check(font),
        FAIL,
        "bad-vertical-diagonal-spacing",
        "with bad spacing between vertical and diagonal strokes...",
    )

    font = TEST_FILE("montserrat/Montserrat-Black.ttf")
    # vv touches
    assert_results_contain(
        check(font),
        FAIL,
        "bad-diagonal-diagonal-spacing",
        "with diagonal strokes (vv) that are touching...",
    )


@check_id("iso15008/interword_spacing")
def test_check_iso15008_interword_spacing(check):
    """Check if spacing between words is adequate for display use"""

    font = TEST_FILE("cabin/CabinCondensed-Bold.ttf")
    # lm space is 112; m+space+l space is 286; 286/112 = 255%
    assert_PASS(check(font), "with a good font...")

    font = TEST_FILE("cabin/Cabin-Regular.ttf")
    # lm space is 147; m+space+l space is 341; 341/147 = 232%
    assert_results_contain(
        check(font), FAIL, "bad-interword-spacing", "with bad interword space..."
    )


@check_id("iso15008/interline_spacing")
def test_check_iso15008_interline_spacing(check):
    """Check if spacing between lines is adequate for display use"""

    font = TEST_FILE("cabin/Cabin-Regular.ttf")
    assert_PASS(check(font), "with a good font...")

    font = TEST_FILE("source-sans-pro/TTF/SourceSansPro-Bold.ttf")
    # 39 units at bottom of g + 49 units at top of h + no typolinegap = 88
    # stem width = 147
    assert_results_contain(
        check(font), FAIL, "bad-interline-spacing", "with bad interline space..."
    )
